@@ -10,14 +10,14 @@ from .core import (normalize_chunks, Array, slices_from_chunks, asarray,
                    broadcast_shapes, broadcast_to)
 from .. import sharedict
 from ..base import tokenize
-from ..utils import ignoring, random_state_data
+from ..utils import ignoring, random_state_data, skip_doctest
 
 
 def doc_wraps(func):
     """ Copy docstring from one function to another """
     def _(func2):
         if func.__doc__ is not None:
-            func2.__doc__ = func.__doc__.replace('>>>', '>>').replace('...', '..')
+            func2.__doc__ = skip_doctest(func.__doc__)
         return func2
     return _
 
@@ -217,6 +217,11 @@ class RandomState(object):
                 size = (size,)
 
             chunks = normalize_chunks(chunks, size, dtype=np.float64)
+            if not replace and len(chunks[0]) > 1:
+                    err_msg = ('replace=False is not currently supported for '
+                               'dask.array.choice with multi-chunk output '
+                               'arrays')
+                    raise NotImplementedError(err_msg)
             sizes = list(product(*chunks))
             state_data = random_state_data(len(sizes), self._numpy_state)
 
