@@ -104,6 +104,7 @@ def test_unique_names():
 def test_docs():
     assert 'exponential' in exponential.__doc__
     assert 'exponential' in exponential.__name__
+    assert "# doctest: +SKIP" in normal.__doc__
 
 
 def test_can_make_really_big_random_array():
@@ -267,6 +268,14 @@ def test_choice():
         with pytest.raises(ValueError):
             da.random.choice(a, size=size, chunks=chunks, p=p)
 
+    with pytest.raises(NotImplementedError):
+        da.random.choice(da_a, size=size, chunks=chunks, replace=False)
+
+    # Want to make sure replace=False works for a single-partition output array
+    x = da.random.choice(da_a, size=da_a.shape[0], chunks=-1, replace=False)
+    res = x.compute()
+    assert len(res) == len(np.unique(res))
+
 
 def test_create_with_auto_dimensions():
     with dask.config.set({'array.chunk-size': '128MiB'}):
