@@ -3,6 +3,7 @@ from __future__ import absolute_import, division, print_function
 import difflib
 import functools
 import math
+import numbers
 import os
 
 import numpy as np
@@ -11,6 +12,14 @@ from toolz import frequencies, concat
 from .core import Array
 from ..sharedict import ShareDict
 
+try:
+    AxisError = np.AxisError
+except AttributeError:
+    try:
+        np.array([0]).sum(axis=5)
+    except Exception as e:
+        AxisError = type(e)
+
 
 def allclose(a, b, equal_nan=False, **kwargs):
     if getattr(a, 'dtype', None) != 'O':
@@ -125,3 +134,17 @@ def safe_wraps(wrapped, assigned=functools.WRAPPER_ASSIGNMENTS):
         return functools.wraps(wrapped, assigned=assigned)
     else:
         return lambda x: x
+
+
+def validate_axis(axis, ndim):
+    """ Validate an input to axis= keywords """
+    if isinstance(axis, (tuple, list)):
+        return tuple(validate_axis(ax, ndim) for ax in axis)
+    if not isinstance(axis, numbers.Integral):
+        raise TypeError("Axis value must be an integer, got %s" % axis)
+    if axis < -ndim or axis >= ndim:
+        raise AxisError("Axis %d is out of bounds for array of dimension %d"
+                        % (axis, ndim))
+    if axis < 0:
+        axis += ndim
+    return axis
