@@ -1,6 +1,6 @@
 from __future__ import absolute_import, division, print_function
 
-from collections import OrderedDict, Iterator
+from collections import OrderedDict
 from functools import partial
 from hashlib import md5
 from operator import getitem
@@ -14,7 +14,7 @@ import warnings
 from toolz import merge, groupby, curry, identity
 from toolz.functoolz import Compose
 
-from .compatibility import long, unicode
+from .compatibility import long, unicode, Iterator
 from .context import thread_state
 from .core import flatten, quote, get as simple_get
 from .hashing import hash_buffer_hex
@@ -262,7 +262,6 @@ def unpack_collections(*args, **kwargs):
         else:
             # Treat iterators like lists
             typ = list if isinstance(expr, Iterator) else type(expr)
-
             if typ in (list, tuple, set):
                 tsk = (typ, [_unpack(i) for i in expr])
             elif typ is dict:
@@ -340,12 +339,6 @@ def optimize(*args, **kwargs):
     return repack([r(dsk, *s) for r, s in postpersists])
 
 
-# TODO: remove after deprecation cycle of `dask.optimize` module completes
-from . import optimize as _deprecated_optimize
-for _m in _deprecated_optimize.__all__:
-    setattr(optimize, _m, getattr(_deprecated_optimize, _m))
-
-
 def compute(*args, **kwargs):
     """Compute several dask collections at once.
 
