@@ -16,7 +16,50 @@ class LZMAFile:
                             "To use, install lzmaffi or backports.lzma.")
 LZMA_AVAILABLE = False
 
+
+# From 3.8, Collections Abstract Base Classes will be visible only
+# from collections.abc.
+try:
+    from collections.abc import (
+        Container,
+        Hashable,
+        Iterable,
+        Iterator,
+        Sized,
+        Callable,
+        Sequence,
+        MutableSequence,
+        Set,
+        MutableSet,
+        Mapping,
+        MutableMapping,
+        MappingView,
+        ItemsView,
+        KeysView,
+        ValuesView,
+    )
+except ImportError:
+    from collections import (
+        Container,
+        Hashable,
+        Iterable,
+        Iterator,
+        Sized,
+        Callable,
+        Sequence,
+        MutableSequence,
+        Set,
+        MutableSet,
+        Mapping,
+        MutableMapping,
+        MappingView,
+        ItemsView,
+        KeysView,
+        ValuesView,
+    )
+
 if PY3:
+    import copyreg
     import builtins
     from queue import Queue, Empty
     from itertools import zip_longest
@@ -70,6 +113,7 @@ if PY3:
 
 else:
     import __builtin__ as builtins
+    import copy_reg as copyreg
     from Queue import Queue, Empty
     from itertools import izip_longest as zip_longest, izip as zip
     from StringIO import StringIO
