@@ -10,15 +10,14 @@ import pandas as pd
 from toolz import merge
 
 from .io import _link
+from ...base import get_scheduler
 from ..core import DataFrame, new_dd_object
-from ... import multiprocessing
+from ... import config, multiprocessing
 from ...base import tokenize, compute_as_if_collection
 from ...bytes.utils import build_name_function
 from ...compatibility import PY3
-from ...context import _globals
 from ...delayed import Delayed, delayed
-from ...local import get_sync
-from ...utils import effective_get, get_scheduler_lock
+from ...utils import get_scheduler_lock
 
 
 def _pd_to_hdf(pd_to_hdf, lock, args, kwargs=None):
@@ -35,7 +34,7 @@ def _pd_to_hdf(pd_to_hdf, lock, args, kwargs=None):
     return None
 
 
-def to_hdf(df, path, key, mode='a', append=False, get=None,
+def to_hdf(df, path, key, mode='a', append=False, get=None, scheduler=None,
            name_function=None, compute=True, lock=None, dask_kwargs={},
            **kwargs):
     """ Store Dask Dataframe to Hierarchical Data Format (HDF) files
@@ -93,7 +92,7 @@ def to_hdf(df, path, key, mode='a', append=False, get=None,
 
     Save data to multiple files, using the multiprocessing scheduler:
 
-    >>> df.to_hdf('output-*.hdf', '/data', get=dask.multiprocessing.get) # doctest: +SKIP
+    >>> df.to_hdf('output-*.hdf', '/data', scheduler='processes') # doctest: +SKIP
 
     Specify custom naming scheme.  This writes files as
     '2000-01-01.hdf', '2000-01-02.hdf', '2000-01-03.hdf', etc..
@@ -162,11 +161,15 @@ def to_hdf(df, path, key, mode='a', append=False, get=None,
 
     # If user did not specify scheduler and write is sequential default to the
     # sequential scheduler. otherwise let the _get method choose the scheduler
-    if get is None and 'get' not in _globals and single_node and single_file:
-        get = get_sync
+    if (get is None and
+            not config.get('get', None) and
+            scheduler is None and
+            not config.get('scheduler', None) and
+            single_node and single_file):
+        scheduler = 'single-threaded'
 
     # handle lock default based on whether we're writing to a single entity
-    _actual_get = effective_get(get, df)
+    _actual_get = get_scheduler(get=get, collections=[df], scheduler=scheduler)
     if lock is None:
         if not single_node:
             lock = True
@@ -177,7 +180,7 @@ def to_hdf(df, path, key, mode='a', append=False, get=None,
         else:
             lock = False
     if lock:
-        lock = get_scheduler_lock(get, df)
+        lock = get_scheduler_lock(get, df, scheduler=scheduler)
 
     kwargs.update({'format': 'table', 'mode': mode, 'append': append})
 
@@ -216,7 +219,8 @@ def to_hdf(df, path, key, mode='a', append=False, get=None,
         keys = [(name, i) for i in range(df.npartitions)]
 
     if compute:
-        compute_as_if_collection(DataFrame, dsk, keys, get=get, **dask_kwargs)
+        compute_as_if_collection(DataFrame, dsk, keys, get=get,
+                                 scheduler=scheduler, **dask_kwargs)
         return filenames
     else:
         return delayed([Delayed(k, dsk) for k in keys])
