@@ -12,7 +12,6 @@ from dask.dataframe.io.io import _meta_from_array
 from dask.delayed import Delayed, delayed
 
 from dask.utils import tmpfile
-from dask.local import get_sync
 
 from dask.dataframe.utils import assert_eq, is_categorical_dtype
 
@@ -126,11 +125,11 @@ def test_from_bcolz_multiple_threads():
         d = dd.from_bcolz(t, chunksize=2)
         assert d.npartitions == 2
         assert is_categorical_dtype(d.dtypes['a'])
-        assert list(d.x.compute(get=get_sync)) == [1, 2, 3]
-        assert list(d.a.compute(get=get_sync)) == ['a', 'b', 'a']
+        assert list(d.x.compute(scheduler='sync')) == [1, 2, 3]
+        assert list(d.a.compute(scheduler='sync')) == ['a', 'b', 'a']
 
         d = dd.from_bcolz(t, chunksize=2, index='x')
-        L = list(d.index.compute(get=get_sync))
+        L = list(d.index.compute(scheduler='sync'))
         assert L == [1, 2, 3] or L == [1, 3, 2]
 
         # Names
@@ -150,13 +149,13 @@ def test_from_bcolz():
     d = dd.from_bcolz(t, chunksize=2)
     assert d.npartitions == 2
     assert is_categorical_dtype(d.dtypes['a'])
-    assert list(d.x.compute(get=get_sync)) == [1, 2, 3]
-    assert list(d.a.compute(get=get_sync)) == ['a', 'b', 'a']
-    L = list(d.index.compute(get=get_sync))
+    assert list(d.x.compute(scheduler='sync')) == [1, 2, 3]
+    assert list(d.a.compute(scheduler='sync')) == ['a', 'b', 'a']
+    L = list(d.index.compute(scheduler='sync'))
     assert L == [0, 1, 2]
 
     d = dd.from_bcolz(t, chunksize=2, index='x')
-    L = list(d.index.compute(get=get_sync))
+    L = list(d.index.compute(scheduler='sync'))
     assert L == [1, 2, 3] or L == [1, 3, 2]
 
     # Names
@@ -324,7 +323,7 @@ def test_DataFrame_from_dask_array():
     assert isinstance(df, dd.DataFrame)
     tm.assert_index_equal(df.columns, pd.Index(['a', 'b', 'c']))
     assert list(df.divisions) == [0, 4, 8, 9]
-    assert (df.compute(get=get_sync).values == x.compute(get=get_sync)).all()
+    assert (df.compute(scheduler='sync').values == x.compute(scheduler='sync')).all()
 
     # dd.from_array should re-route to from_dask_array
     df2 = dd.from_array(x, columns=['a', 'b', 'c'])
@@ -340,7 +339,7 @@ def test_Series_from_dask_array():
     assert isinstance(ser, dd.Series)
     assert ser.name == 'a'
     assert list(ser.divisions) == [0, 4, 8, 9]
-    assert (ser.compute(get=get_sync).values == x.compute(get=get_sync)).all()
+    assert (ser.compute(scheduler='sync').values == x.compute(scheduler='sync')).all()
 
     ser = dd.from_dask_array(x)
     assert isinstance(ser, dd.Series)
@@ -515,6 +514,29 @@ def test_from_delayed():
     assert str(e.value).startswith('Metadata mismatch found in `from_delayed`')
 
 
+def test_from_delayed_misordered_meta():
+    df = pd.DataFrame(
+        columns=['(1)', '(2)', 'date', 'ent', 'val'],
+        data=[range(i * 5, i * 5 + 5) for i in range(3)],
+        index=range(3)
+    )
+
+    # meta with different order for columns
+    misordered_meta = pd.DataFrame(
+        columns=['date', 'ent', 'val', '(1)', '(2)'],
+        data=[range(5)]
+    )
+
+    ddf = dd.from_delayed([delayed(lambda: df)()], meta=misordered_meta)
+
+    with pytest.raises(ValueError) as info:
+        #produces dataframe which does not match meta
+        ddf.reset_index().compute()
+    msg = "The columns in the computed data do not match the columns in the" \
+          " provided metadata"
+    assert msg in str(info.value)
+
+
 def test_from_delayed_sorted():
     a = pd.DataFrame({'x': [1, 2]}, index=[1, 10])
     b = pd.DataFrame({'x': [4, 1]}, index=[100, 200])
