@@ -4,7 +4,6 @@ import re
 import textwrap
 from distutils.version import LooseVersion
 
-from collections import Iterator
 import sys
 import traceback
 from contextlib import contextmanager
@@ -19,6 +18,7 @@ except ImportError:
     # pandas < 0.19.2
     from pandas.core.common import is_datetime64tz_dtype
 
+from ..compatibility import PY2, Iterator
 from ..core import get_deps
 from ..local import get_sync
 from ..utils import asciitable, is_arraylike
@@ -477,7 +477,10 @@ def check_meta(x, meta, funcname=None, numeric_equal=True):
         errmsg = ("Expected partition of type `%s` but got "
                   "`%s`" % (type(meta).__name__, type(x).__name__))
     elif isinstance(meta, pd.DataFrame):
-        dtypes = pd.concat([x.dtypes, meta.dtypes], axis=1)
+        kwargs = dict()
+        if PANDAS_VERSION >= LooseVersion('0.23.0'):
+            kwargs['sort'] = True
+        dtypes = pd.concat([x.dtypes, meta.dtypes], axis=1, **kwargs)
         bad = [(col, a, b) for col, a, b in dtypes.fillna('-').itertuples()
                if not equal_dtypes(a, b)]
         if not bad:
@@ -661,7 +664,7 @@ def assert_sane_keynames(ddf):
         assert isinstance(k, (str, bytes))
         assert len(k) < 100
         assert ' ' not in k
-        if sys.version_info[0] >= 3:
+        if not PY2:
             assert k.split('-')[0].isidentifier()
 
 
